@@ -1,3 +1,4 @@
+import logging
 from uuid import uuid4
 from orchestrator.exceptions import OrchestratorMissingParam
 from orchestrator.orchestrator_http import OrchestratorHTTP
@@ -60,6 +61,7 @@ class Queue(OrchestratorHTTP):
             @machine_identifier: the machine's unique identifier
             @specific_content: the specific content of the transaction
         """
+        logging.debug("Starting new transaction")
         endpoint = "/Queues/UiPathODataSvc.StartTransaction"
         format_body_start = {
             "transactionData": {
@@ -70,7 +72,7 @@ class Queue(OrchestratorHTTP):
         }
         if not specific_content:
             format_body_start["transactionData"]["SpecificContent"] = None
-        print(format_body_start)
+        # print(format_body_start)
         url = f"{self.base_url}{endpoint}"
         return self._post(url, body=format_body_start)
 
